@@ -9,10 +9,18 @@
 
 #include <curses.h>
 
-#ifdef C_PANELSUPPORT
+#ifdef C_PANELFUNCTION
 #include <panel.h>
 #endif
 
+#ifdef C_MENUFUNCTION
+#include <menu.h>
+#endif
+
+#ifdef C_FORMFUNCTION
+#include <form.h>
+#endif
+
 #define C_LONGNAME
 #undef  C_LONG0ARGS
 #define C_LONG2ARGS
